# Visual Setup Guide: Confluence MCP + GitHub Copilot

## 📋 Step-by-Step Setup

### Step 1: Install Package
```bash
pip install confluence-scraper-mcp
```

### Step 2: Open VS Code Settings
1. Press `Cmd+,` (Mac) or `Ctrl+,` (Windows/Linux)
2. Click the "Open Settings (JSON)" icon in the top right

### Step 3: Add MCP Configuration

**Option A: Direct VS Code Settings (Simple)**
Add this to your `settings.json`:

```json
{
  "github.copilot.chat.mcpServers": {
    "confluence-rag": {
      "command": "confluence-scraper-mcp",
      "args": [],
      "env": {
        "CONFLUENCE_BASE_URL": "https://your-domain.atlassian.net",
        "CONFLUENCE_TOKEN": "your-api-token",
        "CONFLUENCE_SPACE_KEY": "your-space-key"
      }
    }
  }
}
```

**Option B: MCP Config File (Recommended)**
1. Copy `examples/mcp-config.json` to your project
2. Edit the configuration values
3. Reference it in VS Code `settings.json`:

```json
{
  "github.copilot.chat.mcpConfigPath": "./mcp-config.json"
}
```

### Step 4: Replace Placeholders
- `your-domain.atlassian.net` → Your Confluence URL
- `your-api-token` → Your Confluence API token
- `your-space-key` → Your Confluence space (e.g., "DEV", "DOCS")

### Step 5: Restart VS Code
Close and reopen VS Code to apply the configuration.

### Step 6: Initial Setup
```bash
# Start the server (runs in background)
confluence-mcp --web &

# Crawl your Confluence content
curl -X POST http://localhost:8000/crawl
```

### Step 7: Test with Copilot
1. Open Copilot Chat: `Cmd+I` (Mac) or `Ctrl+I` (Windows/Linux)
2. Ask a question about your documentation:
   ```
   How do we handle API authentication?
   ```

## 🔧 Alternative Configuration Methods

### Method A: Command Palette
1. `Cmd+Shift+P` → "Preferences: Open User Settings (JSON)"
2. Add the MCP configuration

### Method B: Settings UI
1. `Cmd+,` → Search "copilot"
2. Find "GitHub Copilot: MCP Servers"
3. Click "Edit in settings.json"

## ✅ Verification Checklist

- [ ] Package installed: `confluence-mcp --help` works
- [ ] VS Code settings.json updated with MCP config
- [ ] Confluence credentials are correct
- [ ] VS Code restarted after configuration
- [ ] Initial crawl completed successfully
- [ ] Copilot responses include Confluence context

## 🚨 Troubleshooting

### Common Issues:

**1. "Command not found: confluence-scraper-mcp"**
```bash
# Check if installed
pip list | grep confluence-scraper-mcp

# Reinstall if needed
pip install --force-reinstall confluence-scraper-mcp
```

**2. "Authentication failed"**
- Verify your Confluence token has read permissions
- Test token manually:
```bash
curl -H "Authorization: Bearer YOUR_TOKEN" \
     "https://your-domain.atlassian.net/rest/api/content"
```

**3. "No context in Copilot responses"**
- Ensure crawl completed: `curl http://localhost:8000/health`
- Check if data exists: `ls -la data/chroma/`
- Try re-crawling: `curl -X POST http://localhost:8000/crawl`

**4. VS Code doesn't recognize MCP server**
- Restart VS Code completely
- Check Developer Console: `Help → Toggle Developer Tools`
- Verify JSON syntax in settings.json

## 🎯 Usage Examples

Once configured, ask Copilot questions like:

- "What's our deployment process?"
- "How do we implement authentication?"
- "Show me the API documentation for user management"
- "What are our coding standards?"

Copilot will automatically include relevant Confluence content in responses!

## 📚 More Resources

- [Full Setup Guide](COPILOT_SETUP.md)
- [MCP Examples](../examples/)
- [Troubleshooting](COPILOT_SETUP.md#troubleshooting)
